the module bounds
===================

.. currentmodule:: pyLBM.boundary

The module bounds contains the classes needed to treat
the boundary conditions with the LBM formalism

The classes are

.. autosummary::
   :toctree: generated/

   Boundary
   Boundary_method
   bounce_back
   anti_bounce_back
   Neumann
